@@ -7,7 +7,7 @@ import os
 this_dir, this_filename = os.path.split(__file__)
 tokenizerpath = os.path.join(this_dir, "tokenizers", "tokenizer_deda.pickle")
 
-weigthpath = os.path.join(this_dir, "weights", "model_deda.h5")
+weigthpath = os.path.join(this_dir, "weights", "Model_deda.h5")
 
 
 def check_de(string):
